# Changelog

## 0.1.2

- Updated Docs for readthedocs release

## 0.1.1

- Added getBlockRangeInfo to Api class

## 0.1.0

- Fully typed codebase

## 0.0.9

- Fixed quite a few issues with the liquidity pool and some token objects

## 0.0.8

- Dropped python version down to 3.10 for compatibility

## 0.0.7

- Replacing build system with uv

## 0.0.6

- Removed the need for `/` on the end of the rpc url

## 0.0.5

- Added Pool Object to ease use of Liquidity Pools

## 0.0.4

- Added liquidity pool support

## 0.0.3

- Update api test to make ues of only current blocks because of litenodes block limits.
- Updated documentation to compile with sphinx correctly.

## 0.0.2

- Tried to finish all the misc branding stuff that I may have missed

## 0.0.1

- Inital version
